@@ -1,5 +1,6 @@
 use rand::*;
 use basic_dsp::*;
+use basic_dsp::numbers::*;
 use std::ops::Range;
 use num::complex::Complex32;
 use std::panic;
@@ -198,7 +199,7 @@ pub fn create_random_multitones(seed: usize,
     let mut result = vec![0.0; len].to_real_time_vec();
     for _ in 0..number_of_tones {
         let mut arg = vec![0.0; len].to_real_time_vec();
-        arg.map_inplace((), |_, i, _| i as f32);
+        arg.map_inplace((), &|_, i, _| i as f32);
         let freq = rng.gen_range(0.24, 0.76);
         let phase = rng.gen_range(-1.0, 1.0);
         arg.scale(freq);
